/// The Flutter plugin for creating thumbnail from video
///
/// To use, import `package:video_thumbnail/video_thumbnail.dart`.
///
/// See also:
///
///  * [video_thumbnail](https://pub.dev/packages/video_thumbnail)
///
import 'dart:async';
import 'dart:typed_data';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

enum ImageFormat { JPEG, PNG, WEBP }

class VideoThumbnail {
  static const MethodChannel _channel =
      const MethodChannel('com.qr.flutter_toolkit/video_thumbnail/methods');

  static Future<String> thumbnailFile({
    @required String video,
    int quality = 50,
    ImageFormat imageFormat = ImageFormat.PNG,
    int maxHeightOrWidth = 0,
    int timeMs = 0,
  }) async {
    assert(video != null && video.isNotEmpty);
    final reqMap = <String, dynamic>{
      'video': video,
      'format': imageFormat.index,
      'maxhow': maxHeightOrWidth,
      'timeMs': timeMs,
      'quality': quality
    };
    return await _channel.invokeMethod('file', reqMap);
  }

  static Future<Uint8List> thumbnailData({
    @required String video,
    int quality = 50,
    ImageFormat imageFormat = ImageFormat.PNG,
    int maxHeightOrWidth = 0,
    int timeMs = 0,
  }) async {
    assert(video != null && video.isNotEmpty);
    final reqMap = <String, dynamic>{
      'video': video,
      'format': imageFormat.index,
      'maxhow': maxHeightOrWidth,
      'timeMs': timeMs,
      'quality': quality
    };
    return await _channel.invokeMethod('data', reqMap);
  }
}
